@@ -1,11 +1,17 @@
-from tg import TGController, flash, redirect
+from tg import TGController, flash, redirect, tmpl_context
+import libacr
 from libacr.lib import admin_css, url, current_user_id, language, user_can_modify
+import os
 
 __all__ = ['BaseAdminController']
 
 class BaseAdminController(TGController):
+    def _admin_master_path(self):
+        return os.path.join(os.path.dirname(libacr.__file__), 'templates', 'admin', 'admin_master.html')
+
     def __before__(self, *args, **kw):
         admin_css.inject()
+        tmpl_context.acr_admin_master = self._admin_master_path()
 
 from tw.api import WidgetsList
 import tw.forms as widgets
@@ -19,7 +25,7 @@ from libacr.model.content import Tag, Content, Slice, ContentData, Page
 
 def _create_node(**kw):
     page = DBSession.query(Page).filter_by(uid=kw['page']).first()
-    
+
     if not kw.get('skip_permission',False) and not user_can_modify(page):
         flash('You cannot modify that page')
         return redirect(url('/admin'))
@@ -45,5 +51,3 @@ def _create_node(**kw):
     DBSession.add(content)
     DBSession.add(cdata)
     DBSession.add(slice)
-
-
