@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 """Main Controller"""
 
-from tg import expose, flash, require, url, request, redirect, tmpl_context, TGController
+from tg import expose, flash, require, url, request, response, redirect, tmpl_context, TGController
+from tg.controllers import CUSTOM_CONTENT_TYPE
 from pylons.i18n import ugettext as _, lazy_ugettext as l_
-from pylons.controllers.util import abort
+from pylons.controllers.util import abort, etag_cache
 
 from repoze.what import predicates
 
@@ -18,8 +19,10 @@ from libacr.model.core import DBSession
 from libacr.model.content import Page, Slice, Content, View, ContentData
 from libacr.lib import url, get_page_from_urllist, current_user_id, language, user_can_modify
 from libacr.rss import rss_for_slicegroup
+from libacr.views.manager import ViewsManager
 
 from datetime import datetime
+import mimetypes, base64
 
 from turbomail import Message
 from turbomail.control import interface
@@ -59,7 +62,7 @@ class AcrRootController(TGController):
 
         page = DBSession.query(Page).filter_by(uri='default').one()
         return dict(page=page, slice=slice)
-        
+
     @expose(content_type="application/rss+xml")
     def rss(self, sliceid):
         from libacr.views.slice_group import SliceGroupRenderer
@@ -68,12 +71,12 @@ class AcrRootController(TGController):
             u = slice.page.url
         except:
             abort(404, "Slice not found")
-            
+
         if slice.view != 'slicegroup':
             abort(403, "Invalid slice type")
 
         return rss_for_slicegroup(slice)
-        
+
     @expose('libacr.templates.search')
     def search(self, searchid, what):
         search_slice = DBSession.query(Slice).filter_by(uid=searchid).first()
@@ -111,6 +114,29 @@ class AcrRootController(TGController):
             abort(404, "Slice not found")
         return ''
 
+    @expose(content_type=CUSTOM_CONTENT_TYPE)
+    def data(self, sliceid, field):
+        try:
+            slice = DBSession.query(Slice).filter_by(uid=sliceid).one()
+        except Exception, e:
+            abort(404, "Slice not found")
+
+        slice_data = ViewsManager.decode(slice.view, slice.content.data)
+        field_data = slice_data[field]
+
+        if not field_data.startswith('data'):
+            abort(403, "Content is not data")            
+
+        info, encoded_data = field_data.split(',')
+        mtype, encoding = info.split(';')
+        mtype = mtype.split(':', 1)[1]
+
+        response.headers['Content-Type'] = mtype
+        response.headers['Content-Disposition'] = 'attachment;filename=%s' % (field + mimetypes.guess_extension(mtype))
+        etag_cache('%s-%s' % (sliceid, slice.content.data_instance.uid))
+
+        return base64.b64decode(encoded_data)
+
     @expose()
     def sendForm_to_email(self, **kw):
         missing_value = ''
@@ -142,7 +168,7 @@ class AcrRootController(TGController):
            flash('Please specify the following fields: ' + missing_value)
            return redirect(request.headers['Referer'])
 
-        msg = Message(author="admin@acr.it",
+        msg = Message(author="info@axant.it",
                       to=email_address,
                       subject=subject,
                       plain="email"
