@@ -1,5 +1,5 @@
 from libacr.views.slice_group import SliceGroupRenderer
-from pylons.controllers.util import url_for
+from routes import url_for
 from libacr.lib import url
 from webhelpers.feedgenerator import Rss201rev2Feed
 import ConfigParser, StringIO
